clear
use "C:\Users\Brendan\Dropbox\Working Papers\Sanctions and Interests\Replication File_FPA\Master Data.dta"

************************************summary
logit prosanctions2 loggedmigrants, cluster(ccode)
sutex prosanctions2 loggedmigrants migrantshare migrantshare2 ln_transitstock_weighted migrants_plustransit_sd ln_borderdetect libyabill iranbill population unemp pincometax sstax gdpgrowth col distance exportsGDP importsGDP RWPvoteshare immigrantpolicy logged_refugee lnremit if e(sample), minmax nobs

********************************************************************************
***********************************MODELS***************************************
********************************************************************************

**TABLE 1
//Model 1
logit prosanctions2 loggedmigrants, cluster(ccode)
estimates store MODEL1, title(Model 1)
//Model 2
logit prosanctions2 loggedmigrants libyabill iranbill, cluster(ccode)
estimates store MODEL2, title(Model 2)
//Model 3
logit prosanctions2 loggedmigrants libyabill iranbill i.ccode, cluster(ccode)
estimates store MODEL3, title(Model 3)
//Model 4
logit prosanctions2 loggedmigrants libyabill iranbill i.ccode i.party, cluster(ccode)
estimates store MODEL4, title(Model 4)
//Model 5
logit prosanctions2 loggedmigrants population unemployment gdpgrowth distance col libyabill iranbill i.ccode i.party, cluster(ccode)
estimates store MODEL5, title(Model 5)
margins, at(loggedmigrants=(0(1)12)) atmean
marginsplot, xsize(10) ysize(9) addplot(hist loggedmigrants if e(sample), yaxis(2) xscale(range(0(1)12)) xlabel(0(1)12) yscale(range(0(.1)1)) ylabel() yscale(axis(2) range(0 .75) off) lc(white%0) fcolor(sand%25) recast(rbar)) recast(line) recastci(rarea) ciopts(fc(blue%30) lc(white%0)) xtitle(ln(Migrant Stock)) title("") ytitle(Predicted Probability of Voting in Favor of Sanctions) legend(off) graphregion(fcolor(white) lcolor(white))
estout MODEL1 MODEL2 MODEL3 MODEL4 MODEL5, cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{+}$ 0.10 $^{*}$ 0.05 $^{**}$ 0.01 $^{***}$ 0.001) stats(N N_g r2, fmt(0 0 3) label(Observations Countries R$^2$)) label,  using "results1.tex", replace style(tex)

**Table 2
//Model 6
logit prosanctions2 ln_transitstock_weighted if libyabill==1, cluster(ccode)
estimates store MODEL6, title(Model 6)
//Model 7
logit prosanctions2 ln_transitstock_weighted population unemployment gdpgrowth distance col if libyabill==1, cluster(ccode)
estimates store MODEL7, title(Model 7)
///Add transit stock to stocks
replace transitstock_weighted = 0 if transitstock_weighted==.
//Standardize both variables
gen transitstock_sd = (transitstock_weighted-88911.95)/210096.2
gen migrants_sd = (migrants_lag-16052.88)/28429.08
gen migrants_plustransit_sd = migrants_sd+transitstock_sd

//Model 8
logit prosanctions2 migrants_plustransit_sd libyabill iranbill i.ccode i.party, cluster(ccode)
estimates store MODEL8, title(Model 8)

//Model 9
logit prosanctions2 migrants_plustransit_sd population unemployment gdpgrowth distance col libyabill iranbill i.ccode i.party, cluster(ccode)
estimates store MODEL9, title(Model 9)
estout MODEL6 MODEL7 MODEL8 MODEL9, cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{+}$ 0.10 $^{*}$ 0.05 $^{**}$ 0.01 $^{***}$ 0.001) stats(N N_g r2, fmt(0 0 3) label(Observations Countries R$^2$)) label,  using "results2.tex", replace style(tex)

********************************************************************************
**********************************APPENDIX**************************************
********************************************************************************

**Section: Interactive Effects

logit prosanctions2 loggedmigrants RWPvoteshare migrantstockXrwpvote population unemployment gdpgrowth distance col libyabill iranbill i.ccode i.party, cluster(ccode)
estimates store MODELI1, title(Model I1)

logit prosanctions2 c.loggedmigrants##c.immigrantpolicy population unemployment gdpgrowth distance col libyabill iranbill i.party, cluster(ccode)
estimates store MODELI2, title(Model I2)

logit prosanctions2 loggedmigrants sstax migrantstockXsstax population unemployment gdpgrowth distance col libyabill iranbill i.ccode i.party, cluster(ccode)
estimates store MODELI3, title(Model I3)

logit prosanctions2 migrantshare RWPvoteshare migrantshareXrwpvote population unemployment gdpgrowth distance col libyabill iranbill i.ccode i.party, cluster(ccode)
estimates store MODELI4, title(Model I4)

logit prosanctions2 c.migrantshare##c.immigrantpolicy population unemployment gdpgrowth distance col libyabill iranbill i.party, cluster(ccode)
estimates store MODELI5, title(Model I5)

logit prosanctions2 migrantshare sstax migrantshareXsstax population unemployment gdpgrowth distance col libyabill iranbill i.ccode i.party, cluster(ccode)
estimates store MODELI6, title(Model I6)

logit prosanctions2 migrantshare2 RWPvoteshare migrantshare2Xrwpvote population unemployment gdpgrowth distance col libyabill iranbill i.ccode i.party, cluster(ccode)
estimates store MODELI7, title(Model I7)

logit prosanctions2 c.migrantshare2##c.immigrantpolicy population unemployment gdpgrowth distance col libyabill iranbill i.party, cluster(ccode)
estimates store MODELI8, title(Model I8)

logit prosanctions2 migrantshare2 sstax migrantshare2Xsstax population unemployment gdpgrowth distance col libyabill iranbill i.ccode i.party, cluster(ccode)
estimates store MODELI9, title(Model I9)

*Table A4

logit prosanctions2 loggedmigrants population unemployment gdpgrowth distance col immigrantpolicy libyabill iranbill i.party, cluster(ccode)
estimates store MODELA1, title((A1))

logit prosanctions2 loggedmigrants population unemployment gdpgrowth distance col RWPvoteshare libyabill iranbill i.ccode i.party, cluster(ccode)
estimates store MODELA2, title((A2))

logit prosanctions2 loggedmigrants population unemployment gdpgrowth distance col exportsGDP importsGDP libyabill iranbill i.ccode i.party, cluster(ccode)
estimates store MODELA3, title((A3))

logit prosanctions2 loggedmigrants population unemployment gdpgrowth distance col pincometax sstax libyabill iranbill i.ccode i.party, cluster(ccode)
estimates store MODELA4, title((A4))

logit prosanctions2 loggedmigrants population unemployment gdpgrowth distance col logged_refugee libyabill iranbill i.ccode i.party, cluster(ccode)
estimates store MODELA5, title((A5))

logit prosanctions2 loggedmigrants population unemployment gdpgrowth distance col lnremit libyabill iranbill i.ccode i.party, cluster(ccode)
estimates store MODELA6, title((A6))

estout MODELA1 MODELA2 MODELA3 MODELA4 MODELA5 MODELA6, cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{+}$ 0.10 $^{*}$ 0.05 $^{**}$ 0.01 $^{***}$ 0.001) stats(N N_g r2, fmt(0 0 3) label(Observations Countries R$^2$)) label,  using "modelsa1_a6.tex", replace style(tex)

*Figure 2
coefplot MODELA1, bylabel(Model A1) ///
|| MODELA2, bylabel(Model A2) ///
|| MODELA3, bylabel(Model A3) ///
|| MODELA4, bylabel(Model A4) ///
|| MODELA5, bylabel(Model A5) ///
|| MODELA6, bylabel(Model A6) keep(loggedmigrants) nolabel xsize(10) ysize(9) xline(0) graphregion(fcolor(white) lcolor(white))

*Table A5

logit prosanctions2 loggedmigrants libyabill iranbill i.ccode i.party, cluster(ccode)
estimates store MODELA7, title((A7))

logit prosanctions2 loggedmigrants population unemployment gdpgrowth distance col libyabill iranbill i.ccode i.party, cluster(ccode)
estimates store MODELA8, title((A8))

logit prosanctions2 loggedmigrants population unemployment gdpgrowth distance col immigrantpolicy libyabill iranbill i.party, cluster(ccode)
estimates store MODELA9, title((A9))

logit prosanctions2 loggedmigrants population unemployment gdpgrowth distance col RWPvoteshare libyabill iranbill i.ccode i.party, cluster(ccode)
estimates store MODELA10, title((A10))

logit prosanctions2 loggedmigrants population unemployment gdpgrowth distance col exportsGDP importsGDP libyabill iranbill i.ccode i.party, cluster(ccode)
estimates store MODELA11, title((A11))

logit prosanctions2 loggedmigrants population unemployment gdpgrowth distance col pincometax sstax libyabill iranbill i.ccode i.party, cluster(ccode)
estimates store MODELA12, title((A12))

logit prosanctions2 loggedmigrants population unemployment gdpgrowth distance col logged_refugee libyabill iranbill i.ccode i.party, cluster(ccode)
estimates store MODELA13, title((A13))

logit prosanctions2 loggedmigrants population unemployment gdpgrowth distance col lnremit libyabill iranbill i.ccode i.party, cluster(ccode)
estimates store MODELA14, title((A14))

estout MODELA7 MODELA8 MODELA9 MODELA10 MODELA11 MODELA12 MODELA13 MODELA14, cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{+}$ 0.10 $^{*}$ 0.05 $^{**}$ 0.01 $^{***}$ 0.001) stats(N N_g r2, fmt(0 0 3) label(Observations Countries R$^2$)) label,  using "modelsa7_a14.tex", replace style(tex)

*Table A6
logit prosanctions2 migrantshare, cluster(ccode)
estimates store MODELA15, title((A15))

logit prosanctions2 migrantshare libyabill iranbill, cluster(ccode)
estimates store MODELA16, title((A16))

logit prosanctions2 migrantshare libyabill iranbill i.ccode, cluster(ccode)
estimates store MODELA17, title((A17))

logit prosanctions2 migrantshare libyabill iranbill i.ccode i.party, cluster(ccode)
estimates store MODELA18, title((A18))

logit prosanctions2 migrantshare population unemployment gdpgrowth distance col libyabill iranbill i.ccode i.party, cluster(ccode)
estimates store MODELA19, title((A19))

logit prosanctions2 migrantshare population unemployment gdpgrowth distance col immigrantpolicy libyabill iranbill i.party, cluster(ccode)
estimates store MODELA20, title((A20))

logit prosanctions2 migrantshare population unemployment gdpgrowth distance col RWPvoteshare libyabill iranbill i.ccode i.party, cluster(ccode)
estimates store MODELA21, title((A21))

logit prosanctions2 migrantshare population unemployment gdpgrowth distance col exportsGDP importsGDP libyabill iranbill i.ccode i.party, cluster(ccode)
estimates store MODELA22, title((A22))

logit prosanctions2 migrantshare population unemployment gdpgrowth distance col pincometax sstax libyabill iranbill i.ccode i.party, cluster(ccode)
estimates store MODELA23, title((A23))

logit prosanctions2 migrantshare population unemployment gdpgrowth distance col refugees_perhomepop libyabill iranbill i.ccode i.party, cluster(ccode)
estimates store MODELA24, title((A24))

logit prosanctions2 migrantshare population unemployment gdpgrowth distance col lnremit libyabill iranbill i.ccode i.party, cluster(ccode)
estimates store MODELA25, title((A25))

estout MODELA15 MODELA16 MODELA17 MODELA18 MODELA19 MODELA20 MODELA21 MODELA22 MODELA23 MODELA24 MODELA25, cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{+}$ 0.10 $^{*}$ 0.05 $^{**}$ 0.01 $^{***}$ 0.001) stats(N N_g r2, fmt(0 0 3) label(Observations Countries R$^2$)) label,  using "modelsa15_a25.tex", replace style(tex)

*Table A7
logit prosanctions2 migrantshare2, cluster(ccode)
estimates store MODELA26, title((A26))

logit prosanctions2 migrantshare2 libyabill iranbill, cluster(ccode)
estimates store MODELA27, title((A27))

logit prosanctions2 migrantshare2 libyabill iranbill i.ccode, cluster(ccode)
estimates store MODELA28, title((A28))

logit prosanctions2 migrantshare2 libyabill iranbill i.ccode i.party, cluster(ccode)
estimates store MODELA29, title((A29))

logit prosanctions2 migrantshare2 population unemployment gdpgrowth distance col libyabill iranbill i.ccode i.party, cluster(ccode)
estimates store MODELA30, title((A30))

logit prosanctions2 migrantshare2 population unemployment gdpgrowth distance col immigrantpolicy libyabill iranbill i.party, cluster(ccode)
estimates store MODELA31, title((A31))

logit prosanctions2 migrantshare2 population unemployment gdpgrowth distance col RWPvoteshare libyabill iranbill i.ccode i.party, cluster(ccode)
estimates store MODELA32, title((A32))

logit prosanctions2 migrantshare2 population unemployment gdpgrowth distance col exportsGDP importsGDP libyabill iranbill i.ccode i.party, cluster(ccode)
estimates store MODELA33, title((A33))

logit prosanctions2 migrantshare2 population unemployment gdpgrowth distance col pincometax sstax libyabill iranbill i.ccode i.party, cluster(ccode)
estimates store MODELA34, title((A34))

logit prosanctions2 migrantshare2 population unemployment gdpgrowth distance col refugees_pertotmigrants libyabill iranbill i.ccode i.party, cluster(ccode)
estimates store MODELA35, title((A35))

logit prosanctions2 migrantshare2 population unemployment gdpgrowth distance col lnremit libyabill iranbill i.ccode i.party, cluster(ccode)
estimates store MODELA36, title((A36))

estout MODELA26 MODELA27 MODELA28 MODELA29 MODELA30 MODELA31 MODELA32 MODELA33 MODELA34 MODELA35 MODELA36, cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{+}$ 0.10 $^{*}$ 0.05 $^{**}$ 0.01 $^{***}$ 0.001) stats(N N_g r2, fmt(0 0 3) label(Observations Countries R$^2$)) label,  using "modelsa26_a36.tex", replace style(tex)

*Table A8 (Fractional Logit Models)

///bysort ccode bill: egen avgprosanctionsvote = mean(prosanctions2)
collapse avgprosanctionsvote loggedmigrants population unemployment gdpgrowth distance col immigrantpolicy RWPvoteshare exportsGDP importsGDP pincometax sstax logged_refugee lnremit, by(ccode bill)

fracreg logit avgprosanctionsvote loggedmigrants
estimates store MODELA37, title((A37))

fracreg logit avgprosanctionsvote loggedmigrants i.bill
estimates store MODELA38, title((A38))

fracreg logit avgprosanctionsvote loggedmigrants i.bill i.ccode
estimates store MODELA39, title((A39))

fracreg logit avgprosanctionsvote loggedmigrants population unemployment gdpgrowth distance col i.bill i.ccode
estimates store MODELA40, title((A40))

fracreg logit avgprosanctionsvote loggedmigrants population unemployment gdpgrowth distance col immigrantpolicy i.bill
estimates store MODELA41, title((A41))

fracreg logit avgprosanctionsvote loggedmigrants population unemployment gdpgrowth distance col RWPvoteshare i.bill i.ccode
estimates store MODELA42, title((A42))

fracreg logit avgprosanctionsvote loggedmigrants population unemployment gdpgrowth distance col exportsGDP importsGDP i.bill i.ccode
estimates store MODELA43, title((A43))

fracreg logit avgprosanctionsvote loggedmigrants population unemployment gdpgrowth distance col pincometax sstax i.bill i.ccode
estimates store MODELA44, title((A44))

fracreg logit avgprosanctionsvote loggedmigrants population unemployment gdpgrowth distance col logged_refugee i.bill i.ccode
estimates store MODELA45, title((A45))

fracreg logit avgprosanctionsvote loggedmigrants population unemployment gdpgrowth distance col lnremit i.bill i.ccode
estimates store MODELA46, title((A46))

estout MODELA37 MODELA38 MODELA39 MODELA40 MODELA41 MODELA42 MODELA43 MODELA44 MODELA45 MODELA46, cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{+}$ 0.10 $^{*}$ 0.05 $^{**}$ 0.01 $^{***}$ 0.001) stats(N N_g r2, fmt(0 0 3) label(Observations Countries R$^2$)) label,  using "modelsa37_a46.tex", replace style(tex)

*Table A9 (Mixed Effects)
clear
use "C:\Users\Brendan\Dropbox\Working Papers\Sanctions and Interests\Replication File_FPA\Master Data.dta"

melogit prosanctions2 loggedmigrants libyabill iranbill i.party || ccode:
estimates store MODELA47, title((A47))

melogit prosanctions2 loggedmigrants population unemployment gdpgrowth distance col libyabill iranbill  || ccode:
estimates store MODELA48, title((A48))

melogit prosanctions2 loggedmigrants population unemployment gdpgrowth distance col immigrantpolicy libyabill iranbill i.party || ccode:
estimates store MODELA49, title((A49))

melogit prosanctions2 loggedmigrants population unemployment gdpgrowth distance col RWPvoteshare libyabill iranbill i.party || ccode:
estimates store MODELA50, title((A50))

melogit prosanctions2 loggedmigrants population unemployment gdpgrowth distance col exportsGDP importsGDP libyabill iranbill i.party || ccode:
estimates store MODELA51, title((A51))

melogit prosanctions2 loggedmigrants population unemployment gdpgrowth distance col pincometax sstax libyabill iranbill  i.party || ccode:
estimates store MODELA52, title((A52))

melogit prosanctions2 loggedmigrants population unemployment gdpgrowth distance col logged_refugee libyabill iranbill i.party || ccode:
estimates store MODELA53, title((A53))

melogit prosanctions2 loggedmigrants population unemployment gdpgrowth distance col lnremit libyabill iranbill i.party || ccode:
estimates store MODELA54, title((A54))

estout MODELA47 MODELA48 MODELA49 MODELA50 MODELA51 MODELA52 MODELA53 MODELA54, cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{+}$ 0.10 $^{*}$ 0.05 $^{**}$ 0.01 $^{***}$ 0.001) stats(N N_g r2, fmt(0 0 3) label(Observations Countries R$^2$)) label,  using "modelsa47_a54.tex", replace style(tex)

*Mediation Results: RWP Vote Share
tab party, gen(partydum)
medeff (regress RWPvoteshare loggedmigrants population unemployment gdpgrowth distance col libyabill iranbill partydum1 partydum2 partydum3 partydum4 partydum5 partydum6 partydum7) (logit prosanctions2 loggedmigrants RWPvoteshare population unemployment gdpgrowth distance col libyabill iranbill partydum1 partydum2 partydum3 partydum4 partydum5 partydum6 partydum7), mediate(RWPvoteshare) treat(loggedmigrants 7.543026 10.486297) sims(1000) seed(23145) vce(cluster ccode) level(90)
estimates store MODELA56, title(Model A56)

estout MODELA56, cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{+}$ 0.10 $^{*}$ 0.05 $^{**}$ 0.01 $^{***}$ 0.001) stats(N N_g r2, fmt(0 0 3) label(Observations Countries R$^2$)) label,  using "modelsa55_a56.tex", replace style(tex)

**Mediation Results: Remittances
medeff (regress lnremit loggedmigrants population unemployment gdpgrowth distance col libyabill iranbill partydum1 partydum2 partydum3 partydum4 partydum5 partydum6 partydum7) (logit prosanctions2 loggedmigrants lnremit population unemployment gdpgrowth distance col libyabill iranbill partydum1 partydum2 partydum3 partydum4 partydum5 partydum6 partydum7), mediate(lnremit) treat(loggedmigrants 7.543026 10.486297) sims(1000) seed(23145) vce(cluster ccode) level(90)
estimates store MODELA58, title(Model A58)

estout MODELA58, cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{+}$ 0.10 $^{*}$ 0.05 $^{**}$ 0.01 $^{***}$ 0.001) stats(N N_g r2, fmt(0 0 3) label(Observations Countries R$^2$)) label,  using "modelsa57_a58.tex", replace style(tex)

**Border Dections
logit prosanctions2 ln_borderdetect, cluster(ccode)
estimates store MODELA59, title(Model A59)
//Model 2
logit prosanctions2 ln_borderdetect libyabill iranbill, cluster(ccode)
estimates store MODELA60, title(Model A60)
//Model 3
logit prosanctions2 ln_borderdetect libyabill iranbill i.ccode, cluster(ccode)
estimates store MODELA61, title(Model A61)
//Model 4
logit prosanctions2 ln_borderdetect libyabill iranbill i.ccode i.party, cluster(ccode)
estimates store MODELA62, title(Model A62)
//Model 5
logit prosanctions2 ln_borderdetect population unemployment gdpgrowth distance col libyabill iranbill i.ccode i.party, cluster(ccode)
estimates store MODELA63, title(Model A63)
estout MODELA59 MODELA60 MODELA61 MODELA62 MODELA63, cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{+}$ 0.10 $^{*}$ 0.05 $^{**}$ 0.01 $^{***}$ 0.001) stats(N N_g r2, fmt(0 0 3) label(Observations Countries R$^2$)) label,  using "modelsa59_a63.tex", replace style(tex)


























/////////////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////Old Stuff//////////////////////////////////////////
/////////////////////////////////////////////////////////////////////////////////////////////




///////Interaciton with Party
//Model A54
logit prosanctions2 c.loggedmigrants##c.ECR, cluster(ccode)
estimates store MODELA54, title((A54))

logit prosanctions2 c.loggedmigrants##c.ECR population unemployment gdpgrowth distance col, cluster(ccode)
estimates store MODELA55, title((A55))

logit prosanctions2 c.loggedmigrants##c.ECR population unemployment gdpgrowth distance col libyabill iranbill, cluster(ccode)
estimates store MODELA56, title((A56))

logit prosanctions2 c.loggedmigrants##c.ECR population unemployment gdpgrowth distance col libyabill iranbill i.ccode, cluster(ccode)
estimates store MODELA57, title((A57))
estout MODELA54 MODELA55 MODELA56 MODELA57, cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{+}$ 0.10 $^{*}$ 0.05 $^{**}$ 0.01 $^{***}$ 0.001) stats(N N_g r2, fmt(0 0 3) label(Observations Countries R$^2$)) label,  using "partyinteraction.tex", replace style(tex)
